@@ -46,11 +46,11 @@ public:
     /**
      * Returns the meta data.
      */
-    QVariantMap metaData() const;
+    [[nodiscard]] QVariantMap metaData() const;
 
-    QByteArray type() const override;
+    [[nodiscard]] QByteArray type() const override;
     Attribute *clone() const override;
-    QByteArray serialized() const override;
+    [[nodiscard]] QByteArray serialized() const override;
     void deserialize(const QByteArray &data) override;
 
 private:
