@@ -21,7 +21,10 @@ class AKONADI_CONTACT_CORE_EXPORT EmailAddressSelectionProxyModel : public Akona
     Q_OBJECT
 
 public:
-    enum Role { NameRole = ContactsTreeModel::DateRole + 1, EmailAddressRole };
+    enum Role {
+        NameRole = ContactsTreeModel::DateRole + 1,
+        EmailAddressRole
+    };
 
     explicit EmailAddressSelectionProxyModel(QObject *parent = nullptr);
     ~EmailAddressSelectionProxyModel() override;
